@@ -168,14 +168,17 @@ def add_run_group(analysis_class_parser):
     """
     run_group = analysis_class_parser.add_argument_group(
         title="Analysis Run Parameters",
-        description="Genereal parameters specific for running the analysis")
+        description="Genereal parameters specific for running the analysis. "
+                    "Parameters can be given in terms of frames (e.g. 12) "
+                    "or as a time ('12ps'). Allowed time units are "
+                    "'ps', 'fs' and 'ns'.")
 
     run_group.add_argument(
         "-b",
         dest="start",
         type=str,
         default="0",
-        help="frame or start time for evaluation. (default: %(default)s)"
+        help="start frame or time for evaluation (default: %(default)s)"
         )
 
     run_group.add_argument(
@@ -183,7 +186,7 @@ def add_run_group(analysis_class_parser):
         dest="stop",
         type=str,
         default="-1",
-        help="frame or end time for evaluation. (default: %(default)s)"
+        help="end frame or time for evaluation (default: %(default)s)"
         )
 
     run_group.add_argument(
@@ -191,7 +194,7 @@ def add_run_group(analysis_class_parser):
         dest="step",
         type=str,
         default="1",
-        help="step or time step for evaluation. (default: %(default)s)"
+        help="step or time step for evaluation (default: %(default)s)"
         )
 
     run_group.add_argument(
@@ -303,10 +306,11 @@ def add_cli_universe(parser, name=''):
         default=None,
         nargs="+",
         help="Manually set/overwrite the simulation box dimensions to a "
-        "vector containing unit cell dimensions [a, b, c, α, β, γ], "
-        "lengths a, b, c are in Å, and angles α, β, γ are in degrees. "
+        "vector containing unit cell dimensions "
+        "[a, b, c, alpha, beta, gamma], lengths a, b, c are in angstrom, "
+        "and angles alpha, beta, gamma are in degrees. "
         "Providing only three parameters will assume a rectengular simulation "
-        "box (α = β = γ = 90°).")
+        "box (alpha = beta = gamma = 90°).")
 
 
 def create_CLI(sub_parser, interface_name, parameters):
